power_cogs
==================

.. image:: https://img.shields.io/pypi/v/power_cogs.svg
    :target: https://pypi.python.org/pypi/power_cogs
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status

A template for deep learning projects utilizing hydra for configuration, ray for execution, mlflow, tensorboard, and w&b for metrics + artifact collection

Usage
-----

run `python setup_project.py` and enter new project name to change paths


Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`power_cogs` was written by `Shyam Sudhakaran <shyamsnair97@gmail.com>`_.
